@@ -39,7 +39,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <alsa/asoundlib.h>
-#include <sound/hdsp.h>
+#include <alsa/sound/hdsp.h>
 #include "HDSPMixerCard.h"
 #include "HDSPMixerInputs.h"
 #include "HDSPMixerOutputs.h"
@@ -73,8 +73,8 @@ public:
     Fl_Scroll *scroll;
     HDSPMixerSetup *setup;
     HDSPMixerAbout *about;
-    HDSPMixerPresetData *data[3][3][8]; /* data[card number][mode(ss/ds/qs)][preset number] */
-    HDSPMixerCard *cards[3];
+    HDSPMixerPresetData *data[MAX_CARDS][3][NUM_PRESETS]; /* data[card number][mode(ss/ds/qs)][preset number] */
+    HDSPMixerCard *cards[MAX_CARDS];
     HDSPMixerInputs *inputs;
     HDSPMixerPlaybacks *playbacks;
     HDSPMixerOutputs *outputs;
@@ -93,6 +93,10 @@ public:
     void refreshMixerStrip(int idx, int src);
     void save();
     void load();
+    void setTitle(std::string suffix);
+    void setTitleWithFilename();
+    void stashPreset();
+    void unstashPreset();
 };
 
 #endif
